==> mastapy-14.0.0b2.tar.gz: mastapy-14.0.0b2/mastapy/_private/_internal/implicit/enum_with_selected_value/degree_of_freedom.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""
from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.math_utility import _1550
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import List, Type, Any, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_DegreeOfFreedom")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_DegreeOfFreedom",)


class EnumWithSelectedValue_DegreeOfFreedom(mixins.EnumWithSelectedValueMixin, Enum):
    """EnumWithSelectedValue_DegreeOfFreedom

    A specific implementation of 'EnumWithSelectedValue' for 'DegreeOfFreedom' types.
    """

    __qualname__ = "DegreeOfFreedom"

    @classmethod
    def wrapper_type(cls: "Type[EnumWithSelectedValue_DegreeOfFreedom]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_DegreeOfFreedom]",
    ) -> "_1550.DegreeOfFreedom":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _1550.DegreeOfFreedom
        """
        return _1550.DegreeOfFreedom

    @classmethod
    def implicit_type(cls: "Type[EnumWithSelectedValue_DegreeOfFreedom]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _1550.DegreeOfFreedom.type_()

    @property
    def selected_value(self: "Self") -> "_1550.DegreeOfFreedom":
        """mastapy._private.math_utility.DegreeOfFreedom

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_1550.DegreeOfFreedom]":
        """List[mastapy._private.math_utility.DegreeOfFreedom]

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.1.0b2.tar.gz: mastapy-14.1.0b2/mastapy/_private/_internal/implicit/enum_with_selected_value/degree_of_freedom.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.math_utility import _1563

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_DegreeOfFreedom")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_DegreeOfFreedom",)


class EnumWithSelectedValue_DegreeOfFreedom(mixins.EnumWithSelectedValueMixin, Enum):
    """EnumWithSelectedValue_DegreeOfFreedom

    A specific implementation of 'EnumWithSelectedValue' for 'DegreeOfFreedom' types.
    """

    __qualname__ = "DegreeOfFreedom"

    @classmethod
    def wrapper_type(cls: "Type[EnumWithSelectedValue_DegreeOfFreedom]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_DegreeOfFreedom]",
    ) -> "_1563.DegreeOfFreedom":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _1563.DegreeOfFreedom
        """
        return _1563.DegreeOfFreedom

    @classmethod
    def implicit_type(cls: "Type[EnumWithSelectedValue_DegreeOfFreedom]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _1563.DegreeOfFreedom.type_()

    @property
    def selected_value(self: "Self") -> "_1563.DegreeOfFreedom":
        """mastapy.math_utility.DegreeOfFreedom

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_1563.DegreeOfFreedom]":
        """List[mastapy.math_utility.DegreeOfFreedom]

        Note:
            This property is readonly.
        """
        return None
